==> hledger-web-1.9.2-19-x86_64.pkg.tar.xz: usr/share/haskell/register/hledger-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-web
version: 1.9.2
id: hledger-web-1.9.2-96jT8wr5wbsJCWSile4bIW
key: hledger-web-1.9.2-96jT8wr5wbsJCWSile4bIW
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Web interface for the hledger accounting tool
description:
    This is hledger'\''s web interface.
    It provides a more user-friendly and collaborative UI than the
    command-line or curses-style interfaces.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
abi: ab0ce782c6d3717dea63824c7352c7c2
exposed: True
exposed-modules:
    Application Foundation Handler.AddForm Handler.Common
    Handler.JournalR Handler.RegisterR Handler.RootR Handler.SidebarR
    Handler.Utils Hledger.Web Hledger.Web.Main Hledger.Web.WebOptions
    Import Settings Settings.Development Settings.StaticFiles
hidden-modules: Paths_hledger_web
import-dirs: /usr/lib/ghc-8.4.3/site-local/hledger-web-1.9.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/hledger-web-1.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger-web
hs-libraries: HShledger-web-1.9.2-96jT8wr5wbsJCWSile4bIW
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx base-4.11.1.0
    base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6
    blaze-html-0.9.0.1-GE6MVgSdj1NIDsAcI8SbsY
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug bytestring-0.10.8.2
    clientsession-0.9.1.2-H2S7Xvy26tE9fMPSqFpznW
    cmdargs-0.10.20-DuSx78jNQymI404wla4i2p
    conduit-extra-1.3.0-LPbDnKSN2ul3nZsfv5pZpk
    data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0 directory-1.3.1.5
    filepath-1.4.2 hjsmin-0.2.0.2-AN8aCHidyxO8ckJRbczjO8
    hledger-1.9.1-3tqFYir4GdG60d1o13gaoi
    hledger-lib-1.9.1-1ijLZ710KNLFRE9aWLVfIY
    http-client-0.5.12.1-5df1JMGB44TITKfGVP9tUt
    http-conduit-2.3.1-2QcOcmIjz7KKYYIzSmEOxn
    json-0.9.2-CSdog26Dq1kKFLQDw9tobB
    megaparsec-6.5.0-4exNIF2FCXu5RotZG2bxEP mtl-2.2.2 parsec-3.1.13.0
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    shakespeare-2.0.15-4eWlMmN9FC7GMOljgNqJiK template-haskell-2.13.0.0
    text-1.2.3.0 time-1.8.0.2 transformers-0.5.5.0
    wai-3.2.1.2-BjOwC5r0Ss1K8LAfKu1hRQ
    wai-extra-3.0.22.1-7mQNBtuywMpJ4tPiE5pJlc
    wai-handler-launch-3.0.2.4-GtFEMSfTHJ7ESA22U6tjsi
    warp-3.2.22-LnzF0rjsr8o6SZXdtZBUMs
    yaml-0.8.30-E4V0r2gJCvE1Q0XogkBy7s
    yesod-1.6.0-4UvCDP9rl1VD9XoyvbNdhm
    yesod-core-1.6.5-9COQyAtFK0VLT3btW3mqHb
    yesod-form-1.6.1-L1YnyqyFgiOKssQXDV6axM
    yesod-static-1.6.0-90lauLrmJUfIcWSUd00UlL
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=1d75d8a5e04e09d5efbd2d425663f665
             blaze-html-0.9.0.1-GE6MVgSdj1NIDsAcI8SbsY=43b83c83491e79cea0945c2a1892e4c6
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=18a52ecde9bf04c66bdf9a0cefc08348
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             clientsession-0.9.1.2-H2S7Xvy26tE9fMPSqFpznW=d965198750403fb830b8b2b2c710a501
             cmdargs-0.10.20-DuSx78jNQymI404wla4i2p=a51a70da70fea2284f20b4e90220083e
             conduit-extra-1.3.0-LPbDnKSN2ul3nZsfv5pZpk=8970e64cb3ce59c76093052ed76e8e91
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=df69bf1546f6b4e11e877584feeeb61a
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             hjsmin-0.2.0.2-AN8aCHidyxO8ckJRbczjO8=d8daa2345d1d457cd82a785d00e0efbe
             hledger-1.9.1-3tqFYir4GdG60d1o13gaoi=5542c7eecce82eb682291c7af035ecd2
             hledger-lib-1.9.1-1ijLZ710KNLFRE9aWLVfIY=89164da780a57005e78e2cdb410789ce
             http-client-0.5.12.1-5df1JMGB44TITKfGVP9tUt=e4d950670846f429b8b72a9067d86456
             http-conduit-2.3.1-2QcOcmIjz7KKYYIzSmEOxn=65f002ff859eea74af921615c24419c3
             json-0.9.2-CSdog26Dq1kKFLQDw9tobB=565e21b24c351c4d8f21fb8ceec441ac
             megaparsec-6.5.0-4exNIF2FCXu5RotZG2bxEP=d07b82870ace4c9839555609ba2e2d51
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=f24d7708a3245ecd805ff7d598d8872c
             shakespeare-2.0.15-4eWlMmN9FC7GMOljgNqJiK=c10c8a2373f06eaef28160f214b530ef
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             wai-3.2.1.2-BjOwC5r0Ss1K8LAfKu1hRQ=a86c58410eaf305343e412264bf7d33a
             wai-extra-3.0.22.1-7mQNBtuywMpJ4tPiE5pJlc=0c190c5bb954afca3b2bcbca2f1caa2e
             wai-handler-launch-3.0.2.4-GtFEMSfTHJ7ESA22U6tjsi=5f24334e5fb2e5f8840df677e7d74c6e
             warp-3.2.22-LnzF0rjsr8o6SZXdtZBUMs=6fd41cb5b4d026cf343b055abd6ffc29
             yaml-0.8.30-E4V0r2gJCvE1Q0XogkBy7s=2b7ef90c7c07c86706c47a86bf02da79
             yesod-1.6.0-4UvCDP9rl1VD9XoyvbNdhm=cad6c5fb1e356bc874245a8145fd20bb
             yesod-core-1.6.5-9COQyAtFK0VLT3btW3mqHb=66728732032de6f5343797fe303b6fbe
             yesod-form-1.6.1-L1YnyqyFgiOKssQXDV6axM=8124cc234ad948334f5f6e4a5c0900d1
             yesod-static-1.6.0-90lauLrmJUfIcWSUd00UlL=9caf1146b9271a6620d89951549340ea
haddock-interfaces: /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html: /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-web-1.9.2-24-x86_64.pkg.tar.xz: usr/share/haskell/register/hledger-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-web
version: 1.9.2
id: hledger-web-1.9.2-BbVhGgoAKbv6SZMqq4Adi7
key: hledger-web-1.9.2-BbVhGgoAKbv6SZMqq4Adi7
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Web interface for the hledger accounting tool
description:
    This is hledger'\''s web interface.
    It provides a more user-friendly and collaborative UI than the
    command-line or curses-style interfaces.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
abi: c2d7bfac08b20f06299cddf9b2a424b1
exposed: True
exposed-modules:
    Application Foundation Handler.AddForm Handler.Common
    Handler.JournalR Handler.RegisterR Handler.RootR Handler.SidebarR
    Handler.Utils Hledger.Web Hledger.Web.Main Hledger.Web.WebOptions
    Import Settings Settings.Development Settings.StaticFiles
hidden-modules: Paths_hledger_web
import-dirs: /usr/lib/ghc-8.4.3/site-local/hledger-web-1.9.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/hledger-web-1.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger-web
hs-libraries: HShledger-web-1.9.2-BbVhGgoAKbv6SZMqq4Adi7
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx base-4.11.1.0
    base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6
    blaze-html-0.9.0.1-GE6MVgSdj1NIDsAcI8SbsY
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug bytestring-0.10.8.2
    clientsession-0.9.1.2-H2S7Xvy26tE9fMPSqFpznW
    cmdargs-0.10.20-DuSx78jNQymI404wla4i2p
    conduit-extra-1.3.0-GVcKZHuJmAnHweUkgtQJOi
    data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0 directory-1.3.1.5
    filepath-1.4.2 hjsmin-0.2.0.2-AN8aCHidyxO8ckJRbczjO8
    hledger-1.9.1-EKy34OshH7vBSqlq6rhDpL
    hledger-lib-1.9.1-1ijLZ710KNLFRE9aWLVfIY
    http-client-0.5.12.1-4fq0shn56Od7awuK8YDmzB
    http-conduit-2.3.1-FhienlkIwH8A6wXHc3wGJd
    json-0.9.2-CSdog26Dq1kKFLQDw9tobB
    megaparsec-6.5.0-4exNIF2FCXu5RotZG2bxEP mtl-2.2.2 parsec-3.1.13.0
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    shakespeare-2.0.15-FZV6ssjAVxcCkg2QuDwMyP template-haskell-2.13.0.0
    text-1.2.3.0 time-1.8.0.2 transformers-0.5.5.0
    wai-3.2.1.2-LKLIDbQRtqgEPtmIr3MYaf
    wai-extra-3.0.22.1-FqjuIlJnoLK5OiY273pPh4
    wai-handler-launch-3.0.2.4-9ytif39xY3814Vu2knuvxX
    warp-3.2.22-GEb3MGHLPmzfhRLx2aE5R
    yaml-0.8.30-5OnKsDFfyOUHk5BZ20fF14
    yesod-1.6.0-5xFkDYrlVR7DnTY6N1er5F
    yesod-core-1.6.5-HF8vbmmZ2YtIN5zybiXNHo
    yesod-form-1.6.1-JA2V6XvciXIzuZuZqcEuj
    yesod-static-1.6.0-BG8xtg6OXk4B1zaK7eQ6uS
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=1d75d8a5e04e09d5efbd2d425663f665
             blaze-html-0.9.0.1-GE6MVgSdj1NIDsAcI8SbsY=43b83c83491e79cea0945c2a1892e4c6
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=18a52ecde9bf04c66bdf9a0cefc08348
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             clientsession-0.9.1.2-H2S7Xvy26tE9fMPSqFpznW=d965198750403fb830b8b2b2c710a501
             cmdargs-0.10.20-DuSx78jNQymI404wla4i2p=a51a70da70fea2284f20b4e90220083e
             conduit-extra-1.3.0-GVcKZHuJmAnHweUkgtQJOi=5c74d7236fcb9207b588e4bbf52b3c29
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=df69bf1546f6b4e11e877584feeeb61a
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             hjsmin-0.2.0.2-AN8aCHidyxO8ckJRbczjO8=d8daa2345d1d457cd82a785d00e0efbe
             hledger-1.9.1-EKy34OshH7vBSqlq6rhDpL=cb329cf6a9e9818c2a51b01a31790551
             hledger-lib-1.9.1-1ijLZ710KNLFRE9aWLVfIY=89164da780a57005e78e2cdb410789ce
             http-client-0.5.12.1-4fq0shn56Od7awuK8YDmzB=c2236fa927fddc114389c89a67558b76
             http-conduit-2.3.1-FhienlkIwH8A6wXHc3wGJd=3826d28dd8d113e94dc5e150759bc4be
             json-0.9.2-CSdog26Dq1kKFLQDw9tobB=565e21b24c351c4d8f21fb8ceec441ac
             megaparsec-6.5.0-4exNIF2FCXu5RotZG2bxEP=d07b82870ace4c9839555609ba2e2d51
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=f24d7708a3245ecd805ff7d598d8872c
             shakespeare-2.0.15-FZV6ssjAVxcCkg2QuDwMyP=0c223dbb3f0a88bbe46ced9c0d77e0f4
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             wai-3.2.1.2-LKLIDbQRtqgEPtmIr3MYaf=8fef4b7f1f92cc00d34b31969465d409
             wai-extra-3.0.22.1-FqjuIlJnoLK5OiY273pPh4=112198dc3278864ee008325f81e10bd7
             wai-handler-launch-3.0.2.4-9ytif39xY3814Vu2knuvxX=bd5326683a403251f584d1a1de98ed7f
             warp-3.2.22-GEb3MGHLPmzfhRLx2aE5R=75c3610515494dd47aec8fbc1380b129
             yaml-0.8.30-5OnKsDFfyOUHk5BZ20fF14=10e689c693567e9b3baffce0c8d91943
             yesod-1.6.0-5xFkDYrlVR7DnTY6N1er5F=5f89becb15f7a16f28bf4aa329022b63
             yesod-core-1.6.5-HF8vbmmZ2YtIN5zybiXNHo=7131437557f5552199e347990729a50e
             yesod-form-1.6.1-JA2V6XvciXIzuZuZqcEuj=5ce0cfde5881262a319ff814fca8fe30
             yesod-static-1.6.0-BG8xtg6OXk4B1zaK7eQ6uS=70b4e7371b0c73aa6d9a4b6c79467721
haddock-interfaces: /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html: /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
